unit UnidadUtilidadFechas;

interface 

uses Windows, SysUtils, DateUtils;

type
  TFileDateKind = (fdkCreated, fdkLastModified, fdkLastAccessed);
  function obtenerFechaFichero (const FileName: string;
      out FileDate: TDateTime; SpecificFileDate: TFileDateKind): boolean;
  function cambiarFechaFichero (const FileName: string;
      FileDate: TDateTime; SpecificFileDate: TFileDateKind): boolean;


implementation  


function obtenerFechaFichero (const FileName: string;
    out FileDate: TDateTime; SpecificFileDate: TFileDateKind): boolean;
var
  fHandle : integer;
  Succeed : boolean;
  FileCreationDate, FileLastModifiedDate, FileLastAccessedDate : TFileTime;
  TempFileTime : TFileTime;
  TempSystemTime : TSystemTime;
begin
  fHandle := FileOpen(FileName, fmShareDenyNone);
  FileDate := 0.0;
  if fHandle < 0 then Succeed := false
  else
  begin
    Succeed := GetFileTime(fHandle, @FileCreationDate,
        @FileLastAccessedDate, @FileLastModifiedDate);
    FileClose(fHandle);
    if Succeed then begin
      case SpecificFileDate of
        fdkCreated : FileTimeToLocalFileTime(FileCreationDate, TempFileTime);
        fdkLastModified : FileTimeToLocalFileTime(FileLastModifiedDate, TempFileTime);
        fdkLastAccessed : FileTimeToLocalFileTime(FileLastAccessedDate, TempFileTime);
      end;
      if FileTimeToSystemTime(TempFileTime, TempSystemTime) then
        FileDate := EncodeDateTime(TempSystemTime.wYear, TempSystemTime.wMonth,
            TempSystemTime.wDay, TempSystemTime.wHour, TempSystemTime.wMinute,
            TempSystemTime.wSecond, TempSystemTime.wMilliSeconds)
      else Succeed := false;
    end;
  end;
  Result := Succeed;
end;




function cambiarFechaFichero (const FileName: string; FileDate: TDateTime;
    SpecificFileDate: TFileDateKind): boolean;
var
  fHandle : integer;
  Succeed : boolean;
  TempFileTime, FinalFileTime : TFileTime;
  TempSystemTime : TSystemTime;
  pFileCreationDate, pFileLastModifiedDate, pFileLastAccessedDate : PFileTime;
begin
  pFileCreationDate := nil;
  pFileLastModifiedDate := nil;
  pFileLastAccessedDate := nil;

  fHandle := FileOpen(FileName, fmShareDenyWrite or fmOpenWrite);
  if fHandle < 0 then Succeed := false
  else
  begin
    DecodeDateTime(FileDate, TempSystemTime.wYear, TempSystemTime.wMonth,
        TempSystemTime.wDay, TempSystemTime.wHour, TempSystemTime.wMinute,
        TempSystemTime.wSecond, TempSystemTime.wMilliSeconds);
    SystemTimeToFileTime(TempSystemTime, TempFileTime);
    LocalFileTimeToFileTime(TempFileTime, FinalFileTime);
    case SpecificFileDate of
      fdkCreated : pFileCreationDate := @FinalFileTime;
      fdkLastModified : pFileLastModifiedDate := @FinalFileTime;
      fdkLastAccessed : pFileLastAccessedDate := @FinalFileTime;
    end;
    Succeed := SetFileTime(fHandle, pFileCreationDate,
        pFileLastAccessedDate, pFileLastModifiedDate);
    FileClose(fHandle);
  end;
  Result := Succeed;
end;



end.
